@@ -1,13 +1,12 @@
 import os
-from commitizen.cz.base import BaseCommitizen
+
 from commitizen import defaults
+from commitizen.cz.base import BaseCommitizen
+from commitizen.cz.utils import multiple_line_breaker, required_validator
+
 __all__ = ["ConventionalCommitsCz"]
 
 
-class NoSubjectException(Exception):
-    ...
-
-
 def parse_scope(text):
     if not text:
         return ""
@@ -23,10 +22,7 @@ def parse_subject(text):
     if isinstance(text, str):
         text = text.strip(".").strip()
 
-    if not text:
-        raise NoSubjectException
-
-    return text
+    return required_validator(text, msg="Subject is required.")
 
 
 class ConventionalCommitsCz(BaseCommitizen):
@@ -121,6 +117,7 @@ class ConventionalCommitsCz(BaseCommitizen):
                     "Body. Motivation for the change and contrast this "
                     "with previous behavior:\n"
                 ),
+                "filter": multiple_line_breaker,
             },
             {
                 "type": "input",
