@@ -1,5 +1,6 @@
 name: str = "cz_conventional_commits"
-config_files: list = ["pyproject.toml", ".cz", "setup.cfg", ".cz.cfg"]
+# TODO: .cz, setup.cfg, .cz.cfg should be removed in 2.0
+config_files: list = ["pyproject.toml", ".cz.toml", ".cz", "setup.cfg", ".cz.cfg"]
 
 # Available settings
 settings: dict = {
@@ -7,7 +8,7 @@ settings: dict = {
     "version": None,
     "files": [],
     "tag_format": None,  # example v$version
-    "bump_message": None  # bumped v$current_version to $new_version
+    "bump_message": None,  # bumped v$current_version to $new_version
 }
 
 MAJOR = "MAJOR"
